@@ -7,17 +7,22 @@ use Data::UUID;
 use parent 'Plack::Middleware';
 use Plack::Util;
 use Plack::Util::Accessor qw/
+    psgi_env_key
     http_header
     id_generator
 /;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our $request_id;
 
 sub prepare_app {
     my ($self) = @_;
 
+    unless ($self->psgi_env_key) {
+        $self->psgi_env_key('psgix.request_id');
+    }
+
     unless ($self->http_header) {
         $self->http_header('X-Request-Id');
     }
@@ -33,7 +38,7 @@ sub prepare_app {
 sub call {
     my($self, $env) = @_;
 
-    $request_id = $env->{'psgix.request_id'}
+    $request_id = $env->{$self->psgi_env_key}
         = $env->{$self->http_header} || $self->id_generator->($env);
 
     my $res = $self->app->($env);
@@ -44,7 +49,7 @@ sub call {
             Plack::Util::header_push(
                 $res->[1],
                 $self->http_header,
-                $env->{'psgix.request_id'},
+                $env->{$self->psgi_env_key},
             );
         }
     });
@@ -77,11 +82,33 @@ use another id generator if you want
             Digest::MD5::md5_hex($$, time(), $env->{PATH_INFO})
         };
 
+See C<MIDDLEWARE OPTIONS> for other options.
+
 =head1 DESCRIPTION
 
 Plack::Middleware::RequestId generates the request id and sets it into HTTP header.
 
 
+=head1 MIDDLEWARE OPTIONS
+
+=head2 psgi_env_key
+
+The key string for storing an ID in PSGI environment variables. default: C<psgix.request_id>
+
+=head2 http_header
+
+The key string for an ID in HTTP Headers. default: C<X-Request-Id>
+
+=head2 id_generator
+
+The code ref for generating an ID. By default, using L<Data::UUID>.
+
+
+=head1 Getting ID TIPS
+
+Normally, you get the request ID from PSGI env. However, the ID has been stored C<$Plack::Middleware::RequestId::request_id> also. So you can get it anywhere.
+
+
 =head1 METHODS
 
 =over
@@ -97,7 +124,7 @@ Plack::Middleware::RequestId generates the request id and sets it into HTTP head
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/Plack-Middleware-RequestId"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-RequestId.png?_t=1443672845"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-RequestId"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-RequestId/badge.png?_t=1443672845&branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/Plack-Middleware-RequestId"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-RequestId.png?_t=1463707503"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-RequestId"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-RequestId/badge.png?_t=1463707503&branch=master"/></a>
 
 =end html
 
@@ -113,6 +140,10 @@ Dai Okabayashi E<lt>bayashi@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
+Rack::RequestId L<https://github.com/anveo/rack-request-id>
+
+L<Data::UUID>
+
 L<Plack::Middleware>
 
 
